@@ -36,6 +36,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 #include <yaz/timing.h>
 #include <yaz/log.h>
 #include <yaz/daemon.h>
+#include <yaz/malloc_info.h>
 #include "gduutil.hpp"
 #include <signal.h>
 
@@ -363,7 +364,7 @@ void yf::FrontendNet::ZAssocChild::report(Z_HTTP_Request *hreq)
             w, "    <response duration_average=\"%f\"/>\n",
             m_p->m_duration_total / number_total);
 
-    wrbuf_puts(w, " </responses>\n");
+    wrbuf_puts(w, "  </responses>\n");
 
     int thread_busy;
     int thread_total;
@@ -372,6 +373,13 @@ void yf::FrontendNet::ZAssocChild::report(Z_HTTP_Request *hreq)
     wrbuf_printf(w, " <thread_info busy=\"%d\" total=\"%d\"/>\n",
                  thread_busy, thread_total);
 
+    wrbuf_malloc_info(w);
+
+    {
+        char buf[200];
+        if (nmem_get_status(buf, sizeof(buf) - 1) == 0)
+            wrbuf_puts(w, buf);
+    }
     wrbuf_puts(w, "</frontend_net>\n");
 
     hres->content_len = w.len();
@@ -827,6 +835,10 @@ void yf::FrontendNet::configure(const xmlNode * ptr, bool test_only,
                                                     ptr->name));
         }
     }
+    if (m_p->m_msg_config.length() > 0 && m_p->m_stat_req.length() == 0)
+    {   // allow stats if message is enabled for filter
+        m_p->m_stat_req = "/fn_stat";
+    }
     if (test_only)
         return;
     set_ports(ports);
